@@ -1,13 +1,16 @@
 # django imports
 from django.db import models
 from django.db.models.query import QuerySet
+from django.conf import settings
 from django.core.cache import cache
 from django.http import Http404
 from django.shortcuts import _get_queryset
 
+
 def key_from_instance(instance):
     opts = instance._meta
-    return '%s.%s:%s' % (opts.app_label, opts.module_name, instance.pk)    
+    return '%s.%s:%s' % (opts.app_label, opts.module_name, instance.pk)
+
 
 class SimpleCacheQuerySet(QuerySet):
     def filter(self, *args, **kwargs):
@@ -16,18 +19,47 @@ class SimpleCacheQuerySet(QuerySet):
             if val in kwargs:
                 pk = kwargs[val]
                 break
-        if pk is not None:            
-            opts = self.model._meta            
-            key = '%s.%s:%s' % (opts.app_label, opts.module_name, pk)
+        if pk is not None:
+            opts = self.model._meta
+            key = '%s.%s.%s:%s' % (settings.CACHE_MIDDLEWARE_KEY_PREFIX, opts.app_label, opts.module_name, pk)
             obj = cache.get(key)
             if obj is not None:
                 self._result_cache = [obj]
         return super(SimpleCacheQuerySet, self).filter(*args, **kwargs)
-        
+
+
 class SimpleCacheManager(models.Manager):
     def get_query_set(self):
-        return SimpleCacheQuerySet(self.model)        
-        
+        return SimpleCacheQuerySet(self.model)
+
+
+def lfs_get_object(klass, *args, **kwargs):
+    """
+    Uses get() to return an object, or raises a Http404 exception if the object
+    does not exist.
+
+    klass may be a Model, Manager, or QuerySet object. All other passed
+    arguments and keyword arguments are used in the get() query.
+
+    Note: Like with get(), an MultipleObjectsReturned will be raised if more than one
+    object is found.
+    """
+    cache_key = "%s-%s-%s" % (settings.CACHE_MIDDLEWARE_KEY_PREFIX, klass.__name__.lower(), kwargs.values()[0])
+    object = cache.get(cache_key)
+    if object is not None:
+        return object
+
+    queryset = _get_queryset(klass)
+
+    try:
+        object = queryset.get(*args, **kwargs)
+    except queryset.model.DoesNotExist:
+        return None
+    else:
+        cache.set(cache_key, object)
+        return object
+
+
 def lfs_get_object_or_404(klass, *args, **kwargs):
     """
     Uses get() to return an object, or raises a Http404 exception if the object
@@ -39,19 +71,21 @@ def lfs_get_object_or_404(klass, *args, **kwargs):
     Note: Like with get(), an MultipleObjectsReturned will be raised if more than one
     object is found.
     """
-    cache_key = "%s-%s" % (klass.__name__.lower(), kwargs.values()[0])
+    cache_key = "%s-%s-%s" % (settings.CACHE_MIDDLEWARE_KEY_PREFIX, klass.__name__.lower(), kwargs.values()[0])
     object = cache.get(cache_key)
     if object is not None:
         return object
-        
+
     queryset = _get_queryset(klass)
     try:
         object = queryset.get(*args, **kwargs)
-        cache.set(cache_key, object)
-        return object
     except queryset.model.DoesNotExist:
         raise Http404('No %s matches the given query.' % queryset.model._meta.object_name)
-        
+    else:
+        cache.set(cache_key, object)
+        return object
+
+
 def clear_cache():
     """Clears the complete cache.
     """
@@ -59,7 +93,7 @@ def clear_cache():
     try:
         cache._cache.flush_all()
     except AttributeError:
-        pass            
+        pass
     else:
         return
 
@@ -71,4 +105,3 @@ def clear_cache():
         cache._expire_info.clear()
     except AttributeError:
         pass
-        
\ No newline at end of file
