@@ -1,4 +1,5 @@
 # django imports
+from django.conf import settings
 from django.core.exceptions import ObjectDoesNotExist
 from django.core.cache import cache
 from django.core.urlresolvers import reverse
@@ -10,29 +11,37 @@ from lfs.payment import utils as payment_utils
 from lfs.shipping import utils as shipping_utils
 from lfs.voucher.models import Voucher
 
+# Load logger
+import logging
+logger = logging.getLogger("default")
+
+
+# DDD
 def get_cart_max_delivery_time(request, cart):
-    """Returns the delivery time object with the maximal delivery time of all
+    """
+    Returns the delivery time object with the maximal delivery time of all
     products within the cart. Takes the selected shipping method into account.
 
     This is used within the cart to display the maximal delivery time.
-    """
-    max_delivery_time = None
-    for item in cart.items():
-        # Calculate the delivery time of the product. Takes the selected
-        # shipping method into account.
-        delivery_time = shipping_utils.get_product_delivery_time(
-            request, item.product.slug, for_cart=True)
-        if (max_delivery_time is None) or \
-           (delivery_time.as_hours() > max_delivery_time.as_hours()):
-            max_delivery_time = delivery_time
-    return max_delivery_time
 
-# TODO: Remove cart from signature?
-def get_cart_price(request, cart, total=False, cached=True):
-    """Returns price of the given cart.
+    This function is DEPRECATED.
     """
+    logger.info("Decprecated: lfs.cart.utils: the function 'get_cart_max_delivery_time' is deprecated. Please use the method 'get_delivery_time' of the Cart object.")
+    return cart.get_delivery_time(request)
+
+
+# DDD
+def get_cart_price(request, cart, total=False, cached=True):
+    """
+    Returns price of the given cart.
+
+    This function is DEPRECATED.
+    """
+    logger.info("Decprecated: lfs.cart.utils: the function 'get_cart_price' is deprecated. Please use the method 'get_max_delivery_time' of the Cart object.")
     return get_cart_costs(request, cart, total, cached)["price"]
 
+
+# DDD
 def get_cart_costs(request, cart, total=False, cached=True):
     """Returns a dictionary with price and tax of the given cart:
 
@@ -40,11 +49,15 @@ def get_cart_costs(request, cart, total=False, cached=True):
             "price" : the cart's price,
             "tax" : the cart's tax,
         }
-    """
-    if cart is None:
-        return {"price" : 0, "tax" : 0}
 
-    cache_key = "cart-costs-%s-%s" % (total, cart.id)
+    This is function DEPRECATED.
+    """
+    logger.info("Decprecated: lfs.cart.utils: the function 'get_cart_costs' is deprecated. Please use the methods 'get_price/get_tax' of the Cart/Shipping/Payment objects.")
+
+    if cart is None:
+        return {"price": 0, "tax": 0}
+
+    cache_key = "%s-cart-costs-%s-%s" % (settings.CACHE_MIDDLEWARE_KEY_PREFIX, total, cart.id)
 
     if cached:
         cart_costs = cache.get(cache_key)
@@ -53,13 +66,13 @@ def get_cart_costs(request, cart, total=False, cached=True):
 
     if cart_costs is None:
 
-        items = cart.items()
+        items = cart.get_items()
 
         cart_price = 0
         cart_tax = 0
         for item in items:
-            cart_price += item.get_price()
-            cart_tax += item.get_tax()
+            cart_price += item.get_price_gross(request)
+            cart_tax += item.get_tax(request)
 
         if len(items) > 0 and total:
             # Shipping
@@ -90,14 +103,16 @@ def get_cart_costs(request, cart, total=False, cached=True):
                 voucher_value = voucher.get_price_gross(cart)
                 cart_price = cart_price - voucher_value
 
-        cart_costs = {"price" : cart_price, "tax" : cart_tax}
+        cart_costs = {"price": cart_price, "tax": cart_tax}
         cache.set(cache_key, cart_costs)
 
     return cart_costs
 
+
 def get_or_create_cart(request):
-    """Returns the cart of the current user. If no cart exists it creates a new
-    one first.
+    """
+    Returns the cart of the current user. If no cart exists yet it creates a
+    new one first.
     """
     cart = get_cart(request)
     if cart is None:
@@ -105,43 +120,52 @@ def get_or_create_cart(request):
 
     return cart
 
+
 def create_cart(request):
-    """Creates a cart for the current session and/or user.
     """
-    cart = Cart(session = request.session.session_key)
+    Creates a cart for the current session and/or user.
+    """
+    cart = Cart(session=request.session.session_key)
     if request.user.is_authenticated():
         cart.user = request.user
 
     cart.save()
     return cart
 
+
 def get_cart(request):
-    """Returns the cart of the current customer or None.
+    """
+    Returns the cart of the current shop customer. if the customer has no cart
+    yet it returns None.
     """
     session_key = request.session.session_key
     user = request.user
 
     if user.is_authenticated():
         try:
-            cart = cache.get("cart-%s" % user)
+            cache_key = "%s-cart-%s" % (settings.CACHE_MIDDLEWARE_KEY_PREFIX, user)
+            cart = cache.get(cache_key)
             if cart is None:
-                cart = Cart.objects.get(user = user)
-                cache.set("cart-%s" % user, cart)
+                cart = Cart.objects.get(user=user)
+                cache.set(cache_key, cart)
             return cart
         except ObjectDoesNotExist:
             return None
     else:
         try:
-            cart = cache.get("cart-%s" % session_key)
+            cache_key = "%s-cart-%s" % (settings.CACHE_MIDDLEWARE_KEY_PREFIX, session_key)
+            cart = cache.get(cache_key)
             if cart is None:
-                cart = Cart.objects.get(session = session_key)
-                cache.set("cart-%s" % session_key, cart)
+                cart = Cart.objects.get(session=session_key)
+                cache.set(cache_key, cart)
             return cart
         except ObjectDoesNotExist:
             return None
 
+
 def get_go_on_shopping_url(request):
-    """Calculates the go on shopping url.
+    """
+    Calculates the go on shopping url based on the last visited category.
     """
     lc = request.session.get("last_category")
     if lc:
@@ -149,8 +173,10 @@ def get_go_on_shopping_url(request):
     else:
         return reverse("lfs_shop_view")
 
+
 def update_cart_after_login(request):
-    """Updates the cart after login.
+    """
+    Updates the cart after login.
 
     1. if there is no session cart, nothing has to be done.
     2. if there is a session cart and no user cart we assign the session cart
@@ -159,16 +185,16 @@ def update_cart_after_login(request):
        to the user cart.
     """
     try:
-        session_cart = Cart.objects.get(session = request.session.session_key)
+        session_cart = Cart.objects.get(session=request.session.session_key)
         try:
-            user_cart = Cart.objects.get(user = request.user)
+            user_cart = Cart.objects.get(user=request.user)
         except ObjectDoesNotExist:
             session_cart.user = request.user
             session_cart.save()
         else:
-            for session_cart_item in session_cart.items():
+            for session_cart_item in session_cart.get_items():
                 try:
-                    user_cart_item = CartItem.objects.get(cart = user_cart, product = session_cart_item.product)
+                    user_cart_item = CartItem.objects.get(cart=user_cart, product=session_cart_item.product)
                 except ObjectDoesNotExist:
                     session_cart_item.cart = user_cart
                     session_cart_item.save()
@@ -177,4 +203,4 @@ def update_cart_after_login(request):
                     user_cart_item.save()
             session_cart.delete()
     except ObjectDoesNotExist:
-        pass
\ No newline at end of file
+        pass
