@@ -224,7 +224,7 @@ def add_to_cart(request, product_id=None):
     product = lfs_get_object_or_404(Product, pk=product_id)
 
     # Only active and deliverable products can be added to the cart.
-    if (product.is_active() and product.deliverable) == False:
+    if (product.is_active() and product.is_deliverable()) == False:
         raise Http404()
 
     try:
