@@ -20,7 +20,7 @@ import lfs.catalog.utils
 import lfs.core.utils
 from lfs.caching.utils import lfs_get_object_or_404
 from lfs.cart.views import add_to_cart
-from lfs.catalog.models import Category
+from lfs.catalog.models import Category, Property
 from lfs.catalog.models import File
 from lfs.catalog.models import Product
 from lfs.catalog.models import ProductPropertyValue
@@ -103,17 +103,15 @@ def calculate_price(request, id):
     for key, option_id in request.POST.items():
         if key.startswith("property"):
             try:
-                po = PropertyOption.objects.get(pk=option_id)
-            except (ValueError, PropertyOption.DoesNotExist):
-                pass
-            else:
-                if po.property.add_price:
-                    try:
+                property_id = int(key.split('-')[1])
+                property = Property.objects.get(pk=property_id)
+                if property.is_select_field:
+                    po = PropertyOption.objects.get(property=property, pk=option_id)
+                    if property.add_price:
                         po_price = float(po.price)
-                    except (TypeError, ValueError):
-                        pass
-                    else:
                         property_price += po_price
+            except (IndexError, ValueError, TypeError, PropertyOption.DoesNotExist, Property.DoesNotExist):
+                pass
 
     if product.for_sale:
         for_sale_standard_price = product.get_standard_price(request, with_properties=False)
