@@ -1,6 +1,9 @@
 # django imports
 import django.dispatch
 
+# Shop
+shop_changed = django.dispatch.Signal()
+
 # Catalog
 cart_changed = django.dispatch.Signal()
 category_changed = django.dispatch.Signal()
@@ -9,9 +12,11 @@ lfs_sorting_changed = django.dispatch.Signal()
 
 # Marketing
 topseller_changed = django.dispatch.Signal()
+featured_changed = django.dispatch.Signal()
 
 # Order
 order_submitted = django.dispatch.Signal()
+order_sent = django.dispatch.Signal()
 
 # Property
 property_type_changed = django.dispatch.Signal()
