@@ -9,6 +9,7 @@ from django.core.cache import cache
 from django.core.exceptions import ObjectDoesNotExist
 from django.core.urlresolvers import reverse
 from django.template import Node, TemplateSyntaxError
+from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
 
 # lfs imports
@@ -159,7 +160,7 @@ def breadcrumbs(context, obj):
         objects = []
         objects.append({
             "name": _(u"Information"),
-            "get_absolute_url": reverse("lfs_pages")}),
+            "url": reverse("lfs_pages")}),
         objects.append({"name": obj.title})
 
         result = {
@@ -221,13 +222,13 @@ def product_navigation(context, product):
             products = Product.objects.filter(
                 categories__in=categories,
                 sub_type__in=(STANDARD_PRODUCT, PRODUCT_WITH_VARIANTS, CONFIGURABLE_PRODUCT),
-            ).order_by(sorting)
+            ).distinct().order_by(sorting)
         else:
             products = Product.objects.filter(
                 categories__in=categories,
                 sub_type__in=(STANDARD_PRODUCT, PRODUCT_WITH_VARIANTS, CONFIGURABLE_PRODUCT),
                 active=True,
-            ).order_by(sorting)
+            ).distinct().order_by(sorting)
 
         product_slugs = [p.slug for p in products]
         product_index = product_slugs.index(slug)
@@ -449,7 +450,7 @@ def currency(value, grouping=True):
         if result[-1] == '-':
             length = len(locale.nl_langinfo(locale.CRNCYSTR))
             result = '%s-%s' % (result[0:length], result[length:-1])
-        return '<span class="negative">%s</span>' % result
+        return mark_safe('<span class="negative">%s</span>' % result)
     return result
 
 @register.filter
@@ -531,7 +532,9 @@ def packages(cart_item):
     amount.
     """
     cart_item = cart_item.get("obj")
-    return int(math.ceil(cart_item.amount / cart_item.product.packing_unit))
+    if cart_item.product.packing_unit:
+        return int(math.ceil(cart_item.amount / cart_item.product.packing_unit))
+    return 0
 
 
 @register.filter(name='get_price')
