@@ -15,4 +15,14 @@ CC_VISA = "VISA"
 CREDIT_CARD_TYPE_CHOICES = (
     (CC_MASTERCARD, _(u"Mastercard")),
     (CC_VISA, _(u"Visacard")),
-)
\ No newline at end of file
+)
+
+PM_PLAIN = 0
+PM_BANK = 1
+PM_CREDIT_CARD = 2
+
+PAYMENT_METHOD_TYPES_CHOICES = (
+    (PM_PLAIN, _(u"Plain")),
+    (PM_BANK, _(u"Bank")),
+    (PM_CREDIT_CARD, _(u"Credit Card")),
+)
