@@ -1,5 +1,6 @@
 # django imports
 from django import forms
+from django.template import RequestContext
 from django.template.loader import render_to_string
 
 # portlets imports
@@ -8,8 +9,9 @@ from portlets.models import Portlet
 # shipping imports
 import lfs.shipping.utils
 
+
 class DeliveryTimePortlet(Portlet):
-    """A portlet to display delivery time.
+    """Portlet to display delivery time.
     """
     class Meta:
         app_label = 'portlet'
@@ -25,27 +27,25 @@ class DeliveryTimePortlet(Portlet):
 
         if product is None:
             d = {
-                "display" : False,
+                "display": False,
             }
         else:
             info = lfs.shipping.utils.get_delivery_time(request, product)
             d = {
-                "display" : True,
-                "title" : self.title,
-                "deliverable" : info["deliverable"],
-                "delivery_time" : info["delivery_time"],
-                "MEDIA_URL" : context.get("MEDIA_URL"),
+                "display": True,
+                "title": self.title,
+                "deliverable": info["deliverable"],
+                "delivery_time": info["delivery_time"],
             }
 
-        return render_to_string("lfs/portlets/delivery_time.html", d)
+        return render_to_string("lfs/portlets/delivery_time.html", RequestContext(request, d))
 
     def form(self, **kwargs):
-        """
-        """
         return DeliveryTimeForm(instance=self, **kwargs)
 
+
 class DeliveryTimeForm(forms.ModelForm):
     """
     """
     class Meta:
-        model = DeliveryTimePortlet
\ No newline at end of file
+        model = DeliveryTimePortlet
