@@ -13,6 +13,7 @@ from lfs.voucher.settings import ABSOLUTE
 from lfs.voucher.settings import PERCENTAGE
 from lfs.voucher.settings import MESSAGES
 
+
 class VoucherOptions(models.Model):
     """Stores misc voucher options
     """
@@ -21,6 +22,7 @@ class VoucherOptions(models.Model):
     number_length = models.IntegerField(blank=True, null=True, default=5)
     number_letters = models.CharField(max_length=100, blank=True, default="ABCDEFGHIJKLMNOPQRSTUVWXYZ")
 
+
 class VoucherGroup(models.Model):
     """Groups vouchers together.
     """
@@ -32,6 +34,7 @@ class VoucherGroup(models.Model):
     class Meta:
         ordering = ("position", )
 
+
 class Voucher(models.Model):
     """A voucher.
 
@@ -83,6 +86,9 @@ class Voucher(models.Model):
 
         - used_date
             The date the voucher has been redeemed.
+
+        - The quanity of how often the voucher can be used. Let it empty
+          the voucher can be used unlimited.
     """
     number = models.CharField(max_length=100, unique=True)
     group = models.ForeignKey(VoucherGroup, related_name="vouchers")
@@ -95,8 +101,9 @@ class Voucher(models.Model):
     value = models.FloatField(default=0.0)
     tax = models.ForeignKey(Tax, verbose_name=_(u"Tax"), blank=True, null=True)
     active = models.BooleanField(default=True)
-    used = models.BooleanField(default=False)
-    used_date = models.DateTimeField(blank=True, null=True)
+    used_amount = models.PositiveSmallIntegerField(default=0)
+    last_used_date = models.DateTimeField(blank=True, null=True)
+    limit = models.PositiveSmallIntegerField(blank=True, null=True, default=1)
 
     class Meta:
         ordering = ("creation_date", "number")
@@ -104,23 +111,23 @@ class Voucher(models.Model):
     def __unicode__(self):
         return self.number
 
-    def get_price_net(self, cart=None):
+    def get_price_net(self, request, cart=None):
         """Returns the net price of the voucher.
         """
         if self.kind_of == ABSOLUTE:
-            return self.value - self.get_tax()
+            return self.value - self.get_tax(request)
         else:
-            return cart.get_price_net() * (self.value / 100)
+            return cart.get_price_net(request) * (self.value / 100)
 
-    def get_price_gross(self, cart=None):
+    def get_price_gross(self, request, cart=None):
         """Returns the gross price of the voucher.
         """
         if self.kind_of == ABSOLUTE:
             return self.value
         else:
-            return cart.get_price_gross() * (self.value / 100)
+            return cart.get_price_gross(request) * (self.value / 100)
 
-    def get_tax(self, cart=None):
+    def get_tax(self, request, cart=None):
         """Returns the absolute tax of the voucher
         """
         if self.kind_of == ABSOLUTE:
@@ -129,27 +136,27 @@ class Voucher(models.Model):
             else:
                 return 0.0
         else:
-            return cart.get_tax()  * (self.value / 100)
+            return cart.get_tax(request) * (self.value / 100)
 
     def mark_as_used(self):
         """Mark voucher as used.
         """
-        self.used = True
-        self.used_date = datetime.datetime.now()
+        self.used_amount += 1
+        self.last_used_date = datetime.datetime.now()
         self.save()
 
-    def is_effective(self, cart):
+    def is_effective(self, request, cart):
         """Returns True if the voucher is effective.
         """
         if self.active == False:
             return (False, MESSAGES[1])
-        if self.used:
+        if (self.limit > 0) and (self.used_amount >= self.limit):
             return (False, MESSAGES[2])
         if self.start_date > datetime.date.today():
             return (False, MESSAGES[3])
         if self.end_date < datetime.date.today():
             return (False, MESSAGES[4])
-        if self.effective_from > cart.get_price_gross():
+        if self.effective_from > cart.get_price_gross(request):
             return (False, MESSAGES[5])
 
         return (True, MESSAGES[0])
@@ -162,4 +169,4 @@ class Voucher(models.Model):
     def is_percentage(self):
         """Returns True if voucher is percentage.
         """
-        return self.kind_of == PERCENTAGE
\ No newline at end of file
+        return self.kind_of == PERCENTAGE
