@@ -4,6 +4,7 @@ import random
 # lfs imports
 from lfs.voucher.models import VoucherOptions
 
+
 def create_voucher_number():
     """
     """
@@ -16,12 +17,24 @@ def create_voucher_number():
         suffix = ""
     else:
         letters = options.number_letters
-        length  = options.number_length
-        prefix  = options.number_prefix
-        suffix  = options.number_suffix
+        length = options.number_length
+        prefix = options.number_prefix
+        suffix = options.number_suffix
 
     number = ""
     for i in range(0, length):
         number += random.choice(letters)
-        
-    return prefix + number + suffix
\ No newline at end of file
+
+    return prefix + number + suffix
+
+
+def get_current_voucher_number(request):
+    """
+    """
+    return request.POST.get("voucher", request.session.get("voucher", ""))
+
+
+def set_current_voucher_number(request, number):
+    """
+    """
+    request.session["voucher"] = number
